@@ -66,7 +66,7 @@ void InfantrySprite::setupTravel(
     GameLogic::Country* dest, 
     const QPointF* dpi)
 {
-  if (dpi ==0) 
+  if (dpi ==nullptr) 
   {
     AnimSprite::setupTravel(src, dest, src->pointInfantry()*m_zoom, dest-> pointInfantry()*m_zoom);
   }
